/*
 * File: FunWithText.java
 * ================================================================
 * A program where we have fun with text!
 */
import acm.program.*;

public class FunWithText extends ConsoleProgram {
	/**
	 * Prints the given string character by character with
	 * a slight pause in-between.
	 * 
	 * @param text The text to print.
	 */
	private void printCharByChar(String text) {
		/* Visit each character one at a time, printing each one out. */
		for (int i = 0; i < text.length(); i++) {
			print(text.charAt(i));
			pause(100);
		}
		
		/* Print a newline at the end. */
		print('\n');
	}
	
	/**
	 * Returns whether the given text string could be a word.  Words aren't
	 * empty and consist solely of letters.
	 * 
	 * @param text The text to check.
	 * @return Whether it's a word.
	 */
	private boolean isWord(String text) {
		/* If the string is empty, it's not a word. */
		if (text.length() == 0) {
			return false;
		}
		
		/* Check whether each character is a letter. */
		for (int i = 0; i < text.length(); i++) {
			char currChar = text.charAt(i);
			
			if (!Character.isLetter(currChar)) {
				return false;
			}
		}
		
		return true;
	}
	
	/**
	 * Reads a word from the user and returns it.
	 * @param prompt The prompt for the word.
	 * @return The word the user entered.
	 */
	private String readWord(String prompt) {
		while (true) {
			/* Grab text from the user.  If it's a word, return it. */
			String text = readLine(prompt);
			if (isWord(text)) {
				return text;
			}
			
			println("Sorry, but that isn't a word.");
		}
	}
	
	public void run() {
		/* We're working with text!  We should be big and bold! */
		setFont("DejaVuSerif-BOLD-32");
		
		String word = readWord("Enter a word: ");
		printCharByChar("You entered " + word);
	}
}
